@@ -1,5 +1,5 @@
 # Copyright (c) 2022, CovidPyLib
-# This file is part of CovidPy v0.1.2
+# This file is part of CovidPy v0.1.4
 #
 # The project has been distributed in the hope it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,7 +12,7 @@ import platform
 import zlib
 import qrcode
 import cbor2
-import importlib.resources as pkg_resources
+import importlib.resources as pkg_resources  # https://stackoverflow.com/questions/6028000/how-to-read-a-static-file-from-inside-a-python-package
 from . import certs
 
 try:
@@ -52,10 +52,12 @@ from cryptography import x509
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.serialization import load_pem_private_key
 import PIL
+import logging
 
 from .verifier import DCCVerifier
 from .types import QRCode, VerifyResult, Certificate
-from .errors import InvalidDCC
+from .errors import InvalidDCC, ImageFormatError
+
 
 class CovidPy:
     def __init__(
@@ -63,17 +65,33 @@ class CovidPy:
         disable_keys_update: bool = False,
         disable_blacklist_update: bool = False,
         disable_blacklist: bool = False,
+        blocked_formats: list = ["EPS"],  # CVE-2018-16509
     ) -> None:
         self.__autoblacklist = disable_blacklist_update
         self.__autokids = disable_keys_update
         self.__disableblacklist = disable_blacklist
         self.__verifier = DCCVerifier(self.__autoblacklist, self.__autokids)
         self.__verifier.load_eu_keys()
+        self.__blocked_formats = blocked_formats
+        if "EPS" not in self.__blocked_formats:
+            logging.warning(
+                "EPS image format should be blocked for secuirity reasons (EPSF), please make sure you know what you are doing"
+            )
         if not self.__disableblacklist:
             self.__verifier.load_blacklist()
 
     def __decodecertificate(self, cert):
-        img = PIL.Image.open(cert) if isinstance(cert, str) else cert.to_bytesio
+        if not isinstance(cert, str):
+            raise TypeError("The given certificate is not a path")
+        img = PIL.Image.open(cert)
+        form = img.format
+        if form in self.__blocked_formats:
+            img.close()
+            raise ImageFormatError(
+                "The given image is in a blocked format, check the 'details' attribute for more details",
+                f"{form}_BLOCKED",
+            )
+        print(form)
         data = pyzbar.pyzbar.decode(img)
         try:
             cert = data[0].data.decode()
@@ -103,13 +121,10 @@ class CovidPy:
                 elif isinstance(value, list):
                     for new_value in value:
                         if isinstance(new_value, dict):
-                            ci_value = new_value.get("ci", None)
-                            return ci_value
+                            return new_value.get("ci", None)
                 elif isinstance(key, str):
-                    if key == "ci":
-                        return value
-                    return None
-            return None    
+                    return value if key == "ci" else None
+            return None
         else:
             raise InvalidDCC(
                 "The given code is not a DCC, check the 'details' attribute for more details",
@@ -128,13 +143,13 @@ class CovidPy:
 
     def __genqr(self, payload: dict):
         cbordata = cbor2.dumps(payload)
-        #with open(f"certs\\dsc-worker.pem", "rb") as file:
+        # with open(f"certs\\dsc-worker.pem", "rb") as file:
         pem = pkg_resources.read_binary(certs, "dsc-worker.pem")
         cert = x509.load_pem_x509_certificate(pem)
         fingerprint = cert.fingerprint(hashes.SHA256())
         keyid = fingerprint[:8]
 
-        #with open(f"certs\\dsc-worker.key", "rb") as file:
+        # with open(f"certs\\dsc-worker.key", "rb") as file:
         pem = pkg_resources.read_binary(certs, "dsc-worker.key")
         keyfile = load_pem_private_key(pem, password=None)
         priv = keyfile.private_numbers().private_value.to_bytes(32, byteorder="big")
@@ -152,7 +167,7 @@ class CovidPy:
 
         out = zlib.compress(msg.encode(), 9)
 
-        out = b"HC1:" + b45encode(out).encode("ascii")
+        out = bytes("HC1:" + str(b45encode(out), "ascii"), "ascii")
 
         return qrcode.make(out), out
 
@@ -170,7 +185,7 @@ class CovidPy:
             return VerifyResult(
                 self.__verifier.is_valid(self.__decodecertificate(cert)), None
             )
-        if revoked and not self.__disableblacklist:
+        if revoked:
             return VerifyResult(False, True)
 
         return VerifyResult(
